# glycopeptide_feature_learning

Tools for modeling how glycopeptides fragment during collisional dissociation for mass spectra.

This project is part of [glycresoft](https://github.com/mobiusklein/glycresoft).